======================
Example Questionnaires
======================

The Microsoft Excel files in this directory demonstrate the xls2xform
syntax. To get a good overview of the syntax look at tutorial.xls.
